@@ -394,11 +394,30 @@ sub _build_bulk_query {
 ## QUERIES
 ##################################
 
+#===================================
+sub _to_dsl {
+#===================================
+    my $self = shift;
+    my $ops  = shift;
+    my $builder;
+    foreach my $clause (@_) {
+        while ( my ( $old, $new ) = each %$ops ) {
+            my $src = delete $clause->{$old} or next;
+            die "Cannot specify $old and $new parameters"
+                if $clause->{$new};
+            $builder ||= $self->builder;
+            my $method = $new eq 'query' ? 'query' : 'filter';
+            $clause->{$new} = $builder->$method($src)->{$method};
+        }
+    }
+}
+
 my %Search_Data = (
     explain       => ['explain'],
     facets        => ['facets'],
     fields        => ['fields'],
     filter        => ['filter'],
+    filterb       => ['filterb'],
     from          => ['from'],
     highlight     => ['highlight'],
     indices_boost => ['indices_boost'],
@@ -406,7 +425,7 @@ my %Search_Data = (
     script_fields => ['script_fields'],
     size          => ['size'],
     'sort'        => ['sort'],
-    track_scores => [ 'track_scores' ],
+    track_scores  => ['track_scores'],
 );
 
 my %SearchQS = (
@@ -419,21 +438,37 @@ my %SearchQS = (
                 )
         ]
     ],
-    preference   => ['string'],
-    routing      => ['flatten'],
-    scroll       => ['duration'],
-    timeout      => ['duration'],
+    preference => ['string'],
+    routing    => ['flatten'],
+    scroll     => ['duration'],
+    timeout    => ['duration'],
 );
 
 my %Search_Defn = (
     cmd     => CMD_index_type,
     postfix => '_search',
-    data    => { %Search_Data, query => ['query'] },
+    data    => { %Search_Data, query => ['query'], queryb => ['queryb'] },
     qs      => {
         %SearchQS,
         scroll  => ['duration'],
         version => [ 'boolean', 1 ]
     },
+    fixup => sub {
+        my $self = shift;
+        my $args = shift;
+        $self->_to_dsl( { queryb => 'query', filterb => 'filter' },
+            $args->{data}, );
+        my @facets = values %{ $args->{data}{facets} || {} };
+        if (@facets) {
+            $self->_to_dsl( {
+                    queryb        => 'query',
+                    filterb       => 'filter',
+                    facet_filterb => 'facet_filter'
+                },
+                @facets,
+            );
+        }
+    }
 );
 
 my %SearchQS_Defn = (
@@ -457,6 +492,8 @@ my %SearchQS_Defn = (
 );
 
 my %Query_Defn = (
+    query              => ['query'],
+    queryb             => ['queryb'],
     bool               => ['bool'],
     boosting           => ['boosting'],
     constant_score     => ['constant_score'],
@@ -483,10 +520,25 @@ my %Query_Defn = (
     span_term          => ['span_term'],
     term               => ['term'],
     terms              => [ 'terms', 'in' ],
+    text               => ['text'],
+    text_phrase        => ['text_phrase'],
+    text_phrase_prefix => ['text_phrase_prefix'],
     top_children       => ['top_children'],
     wildcard           => ['wildcard'],
 );
 
+#===================================
+sub _query_fixup {
+#===================================
+    my $self = shift;
+    my $args = shift;
+    $self->_to_dsl( { queryb => 'query' }, $args->{data} );
+    if ( my $query = delete $args->{data}{query} ) {
+        my ( $k, $v ) = %$query;
+        $args->{data}{$k} = $v;
+    }
+}
+
 #===================================
 sub search   { shift()->_do_action( 'search',   \%Search_Defn,   @_ ) }
 sub searchqs { shift()->_do_action( 'searchqs', \%SearchQS_Defn, @_ ) }
@@ -529,7 +581,8 @@ sub delete_by_query {
                 replication => [ 'enum', [ 'async', 'sync' ] ],
                 routing => ['flatten'],
             },
-            data => \%Query_Defn,
+            data  => \%Query_Defn,
+            fixup => \&_query_fixup,
         },
         @_
     );
@@ -544,6 +597,7 @@ sub count {
             postfix => '_count',
             data    => \%Query_Defn,
             qs      => { routing => ['flatten'] },
+            fixup   => \&_query_fixup,
         },
         @_
     );
@@ -574,6 +628,9 @@ sub mlt {
             },
             postfix => '_mlt',
             data    => \%Search_Data,
+            fixup   => sub {
+                shift()->_to_dsl( { filterb => 'filter' }, $_[0]->{data} );
+            },
         },
         @_
     );
@@ -590,20 +647,27 @@ sub create_percolator {
         {   cmd    => CMD_INDEX_PERC,
             prefix => '_percolator',
             method => 'PUT',
-            data   => { query => 'query', data => ['data'] },
-            fixup  => sub {
+            data   => {
+                query  => ['query'],
+                queryb => ['queryb'],
+                data   => ['data']
+            },
+            fixup => sub {
+                my $self = shift;
                 my $args = shift;
+                $self->_to_dsl( { queryb => 'query' }, $args->{data} );
+                die('create_percolator() requires either the query or queryb param'
+                ) unless $args->{data}{query};
                 die 'The "data" param cannot include a "query" key'
                     if $args->{data}{data}{query};
                 $args->{data} = {
                     query => $args->{data}{query},
                     %{ $args->{data}{data} }
                 };
-                }
+            },
         },
         @_
     );
-
 }
 
 #===================================
@@ -925,9 +989,9 @@ sub put_mapping {
                 _source           => ['_source'],
             },
             fixup => sub {
-                my $args = shift;
+                my $args = $_[1];
                 $args->{data} = { $params->{type} => $args->{data} };
-                }
+            },
 
         },
         $params
@@ -960,6 +1024,7 @@ sub mapping {
         {   method  => 'GET',
             cmd     => CMD_index_type,
             postfix => '_mapping',
+            qs      => { ignore_missing => [ 'boolean', 1 ], }
         },
         $params
     );
@@ -1248,7 +1313,7 @@ sub _do_action {
         $args{qs} = $self->_build_qs( $params, $defn->{qs} );
         $args{data} = $self->_build_data( $params, $defn->{data} );
         if ( my $fixup = $defn->{fixup} ) {
-            $fixup->( \%args );
+            $fixup->( $self, \%args );
         }
         die "Unknown parameters: " . join( ', ', keys %$params ) . "\n"
             if keys %$params;
